@@ -1,6 +1,5 @@
 # :coding: utf-8
 
-import collections
 import os
 import shlex
 
@@ -9,7 +8,6 @@ import wiz.environ
 import wiz.exception
 import wiz.filesystem
 import wiz.graph
-import wiz.logging
 import wiz.package
 import wiz.registry
 import wiz.spawn
@@ -502,120 +500,3 @@ def export_script(
 
     wiz.filesystem.export(file_path, content)
     return file_path
-
-
-def validate_definition(definition, definition_mapping=None):
-    """Return validation mapping for *definition*.
-
-    :param definition: Instance of :class:`wiz.definition.Definition`.
-
-    :param definition_mapping: Mapping regrouping all available definitions. It
-        could be fetched with :func:`fetch_definition_mapping`. If no definition
-        mapping is provided, a default one will be fetched from
-        :func:`default registries <wiz.registry.get_defaults>`.
-
-    :return: Mapping in the form of
-        ::
-
-            {
-                "errors": [],
-                "warnings": []
-            }
-
-    """
-    if definition_mapping is None:
-        definition_mapping = wiz.fetch_definition_mapping(
-            wiz.registry.get_defaults()
-        )
-
-    # Record current logging handlers to set it back once validation is done.
-    _handlers = wiz.logging.root.handlers.copy()
-
-    # Configure logger so that errors and warnings are recorded and not
-    # directly displayed.
-    log_error, log_warning = wiz.logging.configure_for_debug()
-
-    mapping = _fetch_validation_mapping(
-        log_error, log_warning, definition, definition_mapping
-    )
-
-    # Reset logging handlers.
-    wiz.logging.root.handlers = _handlers
-
-    return mapping
-
-
-def _fetch_validation_mapping(
-    log_error, log_warning, definition, definition_mapping
-):
-    """Fetch errors and warnings from definition for *definition*.
-
-    :param log_error: instances of :class:`io.StringIO` such as
-        the instance returned by :func:`wiz.logging.configure_for_debug`. It
-        will receive possible error logged during the context resolution
-        process.
-
-    :param log_warning: instances of :class:`io.StringIO` such as
-        the instance returned by :func:`wiz.logging.configure_for_debug`. It
-        will receive possible warning logged during the context resolution
-        process.
-
-    :param definition: instance of :class:`wiz.definition.Definition`.
-
-    :param definition_mapping: Mapping regrouping all available definitions. It
-        could be fetched with :func:`fetch_definition_mapping`.
-
-    :return: Mapping in the form of
-        ::
-
-            {
-                "errors": [],
-                "warnings": []
-            }
-
-    .. warning::
-
-        *log_error* and *log_warning* variables will be :meth:`closed
-        <io.StringIO.close>` and should not be re-used.
-
-    """
-    mapping = {"errors": [], "warnings": []}
-
-    try:
-        _context = wiz.resolve_context(
-            [definition.qualified_version_identifier],
-            definition_mapping,
-            ignore_implicit=True,
-        )
-
-        error = log_error.getvalue()
-        warning = log_warning.getvalue()
-
-        if len(error) > 0:
-            mapping["errors"].append(error)
-
-        if len(warning) > 0:
-            mapping["warnings"].append(warning)
-
-        log_error.close()
-        log_warning.close()
-
-    except wiz.exception.WizError as error:
-        mapping["errors"].append("critical: {}".format(str(error)))
-
-    else:
-        for key, value in _context.get("environ", {}).items():
-            unresolved_variables = []
-            for variable_tuple in wiz.environ.ENV_PATTERN.findall(value):
-                unresolved_variables.append("".join(variable_tuple))
-
-            if len(unresolved_variables) > 0:
-                warning = (
-                    "warning: the '{}' environment variable contains "
-                    "unresolved elements: {}".format(
-                        key, ", ".join(unresolved_variables)
-                    )
-                )
-                mapping["warnings"].append(warning)
-
-    return mapping
