@@ -4,6 +4,7 @@ import copy
 import collections
 import base64
 import hashlib
+import functools
 
 import pytest
 import six
@@ -441,6 +442,46 @@ def test_update_version_ranges_fail():
     ) in str(error)
 
 
+@pytest.mark.parametrize("versions, expected", [
+    (
+        [
+            "5.3.1", "5.10.0", "5.9.5", "5.1.1", "5.9.4", "5.9.1", "5.9.0",
+            "5.8.2", "5.3.2", "5.2.0", "5.1.0", "5.3.0"
+        ],
+        [
+            "5.1.0", "5.1.1", "5.2.0", "5.3.0", "5.3.1", "5.3.2", "5.8.2",
+            "5.9.0", "5.9.1", "5.9.4", "5.9.5", "5.10.0"
+        ]
+    ),
+    (
+        ["5.3", "5.10", "5.9.0", "5.1", "5.3.2"],
+        ["5.1", "5.3", "5.3.2", "5.9.0", "5.10"]
+    ),
+    (
+        [
+            "4.21.4", "4.21.3", "4.21.2", "1.0.0-alpha", "4.21.1", "4.21.0",
+            "4.1.0", "4.0.0", "4.21.2b0", "3.13.1", "3.13.0", "3.12.0",
+            "1.0.0-beta", "1.0.0-alpha.1", "1.0.0", "1.0.0-beta.2",
+            "1.0.0-beta.11", "4.0.0b0", "1.0.0-rc.1"
+        ],
+        [
+            "1.0.0-alpha", "1.0.0-alpha.1", "1.0.0-beta",
+            "1.0.0-beta.2", "1.0.0-beta.11", "1.0.0-rc.1", "1.0.0", "3.12.0",
+            "3.13.0", "3.13.1", "4.0.0b0", "4.0.0", "4.1.0", "4.21.0", "4.21.1",
+            "4.21.2b0", "4.21.2", "4.21.3", "4.21.4"
+        ]
+    )
+], ids=[
+    "major.minor.patch",
+    "versions-without-patch",
+    "prereleases"
+])
+def test_compare_versions(versions, expected):
+    """Compare list of versions"""
+    compare = functools.cmp_to_key(wiz.utility.compare_versions)
+    assert sorted(versions, key=compare) == expected
+
+
 @pytest.mark.parametrize("definition, expected", [
     (
         wiz.definition.Definition({"identifier": "test"}),
