@@ -1,5 +1,6 @@
 # :coding: utf-8
 
+import copy
 import os
 
 import pytest
@@ -112,6 +113,31 @@ def mocked_utility_decode(mocker):
     return mocker.patch.object(wiz.utility, "decode")
 
 
+@pytest.fixture()
+def mocked_compute_namespace_counter(mocker):
+    """Return mocked 'wiz.utility.compute_namespace_counter' function.
+
+    Ensure that 'requirements' list is copied to better analyze state
+    evolution.
+
+    .. seealso::
+
+        https://docs.python.org/3/library/unittest.mock-examples.html
+        #coping-with-mutable-arguments
+
+    """
+    class _MagicMock(mocker.MagicMock):
+        """Extended mocker to copy namespace counter on each call."""
+
+        def __call__(self, *args, **kwargs):
+            args = copy.deepcopy(args)
+            return super(_MagicMock, self).__call__(*args, **kwargs)
+
+    return mocker.patch.object(
+        wiz.utility, "compute_namespace_counter", _MagicMock()
+    )
+
+
 @pytest.mark.parametrize("options", [
     {},
     {"max_depth": 2},
@@ -233,8 +259,9 @@ def test_fetch_package_request_from_command_error():
 def test_resolve_context(
     mocked_registry_defaults, mocked_fetch_definition_mapping,
     mocked_graph_resolver, mocked_environ_initiate,
-    mocked_package_extract_context, mocked_utility_encode, mocker, options,
-    environ, max_combinations, max_attempts
+    mocked_package_extract_context, mocked_utility_encode,
+    mocked_compute_namespace_counter, mocker, options, environ,
+    max_combinations, max_attempts
 ):
     """Get resolved context mapping."""
     requests = ["test1 >=10, < 11", "test2", "test3[variant]"]
@@ -274,15 +301,20 @@ def test_resolve_context(
     mocked_registry_defaults.assert_not_called()
     mocked_fetch_definition_mapping.assert_not_called()
 
+    mocked_compute_namespace_counter.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        "__PACKAGE_DEFINITIONS__",
+    )
+
     mocked_graph_resolver.assert_called_once_with(
         "__PACKAGE_DEFINITIONS__",
         maximum_combinations=max_combinations,
         maximum_attempts=max_attempts
     )
-    mocked_resolver.compute_packages.assert_called_once_with([
-        Requirement(request) for request in requests
-    ])
-
+    mocked_resolver.compute_packages.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        namespace_counter=mocked_compute_namespace_counter.return_value
+    )
     mocked_environ_initiate.assert_called_once_with(environ)
 
     mocked_package_extract_context.assert_called_once_with(
@@ -304,8 +336,9 @@ def test_resolve_context(
 def test_resolve_context_with_default_definition_mapping(
     mocked_registry_defaults, mocked_fetch_definition_mapping,
     mocked_graph_resolver, mocked_environ_initiate,
-    mocked_package_extract_context, mocked_utility_encode, mocker, options,
-    environ, max_combinations, max_attempts
+    mocked_package_extract_context, mocked_utility_encode,
+    mocked_compute_namespace_counter, mocker, options, environ,
+    max_combinations, max_attempts
 ):
     """Get resolved context mapping with default definition mapping."""
     requests = ["test1 >=10, < 11", "test2", "test3[variant]"]
@@ -345,14 +378,20 @@ def test_resolve_context_with_default_definition_mapping(
     mocked_registry_defaults.asset_called_once()
     mocked_fetch_definition_mapping.asset_called_once_with(paths)
 
+    mocked_compute_namespace_counter.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        "__PACKAGE_DEFINITIONS__",
+    )
+
     mocked_graph_resolver.assert_called_once_with(
         "__PACKAGE_DEFINITIONS__",
         maximum_combinations=max_combinations,
         maximum_attempts=max_attempts
     )
-    mocked_resolver.compute_packages.assert_called_once_with([
-        Requirement(request) for request in requests
-    ])
+    mocked_resolver.compute_packages.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        namespace_counter=mocked_compute_namespace_counter.return_value
+    )
 
     mocked_environ_initiate.assert_called_once_with(environ)
 
@@ -375,8 +414,9 @@ def test_resolve_context_with_default_definition_mapping(
 def test_resolve_context_with_implicit_packages(
     mocked_registry_defaults, mocked_fetch_definition_mapping,
     mocked_graph_resolver, mocked_environ_initiate,
-    mocked_package_extract_context, mocked_utility_encode, mocker, options,
-    environ, max_combinations, max_attempts
+    mocked_package_extract_context, mocked_utility_encode,
+    mocked_compute_namespace_counter, mocker, options, environ,
+    max_combinations, max_attempts
 ):
     """Get resolved context mapping with implicit packages."""
     requests = ["test1 >=10, < 11", "test2", "test3[variant]"]
@@ -418,14 +458,20 @@ def test_resolve_context_with_implicit_packages(
     mocked_registry_defaults.asset_called_once()
     mocked_fetch_definition_mapping.asset_called_once_with(paths)
 
+    mocked_compute_namespace_counter.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        "__PACKAGE_DEFINITIONS__",
+    )
+
     mocked_graph_resolver.assert_called_once_with(
         "__PACKAGE_DEFINITIONS__",
         maximum_combinations=max_combinations,
         maximum_attempts=max_attempts
     )
-    mocked_resolver.compute_packages.assert_called_once_with([
-        Requirement(request) for request in implicit + requests
-    ])
+    mocked_resolver.compute_packages.assert_called_once_with(
+        [Requirement(request) for request in implicit + requests],
+        namespace_counter=mocked_compute_namespace_counter.return_value
+    )
 
     mocked_environ_initiate.assert_called_once_with(environ)
 
@@ -448,8 +494,9 @@ def test_resolve_context_with_implicit_packages(
 def test_resolve_context_with_implicit_packages_ignored(
     mocked_registry_defaults, mocked_fetch_definition_mapping,
     mocked_graph_resolver, mocked_environ_initiate,
-    mocked_package_extract_context, mocked_utility_encode, mocker, options,
-    environ, max_combinations, max_attempts
+    mocked_package_extract_context, mocked_utility_encode,
+    mocked_compute_namespace_counter, mocker, options, environ,
+    max_combinations, max_attempts
 ):
     """Get resolved context mapping with implicit packages ignored."""
     requests = ["test1 >=10, < 11", "test2", "test3[variant]"]
@@ -492,14 +539,20 @@ def test_resolve_context_with_implicit_packages_ignored(
     mocked_registry_defaults.asset_called_once()
     mocked_fetch_definition_mapping.asset_called_once_with(paths)
 
+    mocked_compute_namespace_counter.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        "__PACKAGE_DEFINITIONS__",
+    )
+
     mocked_graph_resolver.assert_called_once_with(
         "__PACKAGE_DEFINITIONS__",
         maximum_combinations=max_combinations,
         maximum_attempts=max_attempts
     )
-    mocked_resolver.compute_packages.assert_called_once_with([
-        Requirement(request) for request in requests
-    ])
+    mocked_resolver.compute_packages.assert_called_once_with(
+        [Requirement(request) for request in requests],
+        namespace_counter=mocked_compute_namespace_counter.return_value
+    )
 
     mocked_environ_initiate.assert_called_once_with(environ)
 
